logging_sync_to_disk

Function logging_sync_to_disk 

pub fn logging_sync_to_disk() -> Result<()>
Flushes and syncs file logs to disk.

This is a no-op when logging is not initialized or file logging is disabled.

Errors

Returns an error if the sync request cannot be delivered or acknowledged.